@@ -6,7 +6,8 @@ RESTful API for SampleDB
 from flask_restful import Resource
 
 from .authentication import multi_auth
-from ...logic.instruments import get_instrument, get_instruments
+from ...logic.instrument_translations import get_instrument_with_translation_in_language, get_instruments_with_translation_in_language
+from ...logic.languages import Language
 from ...logic import errors
 
 __author__ = 'Florian Rhiem <f.rhiem@fz-juelich.de>'
@@ -15,8 +16,8 @@ __author__ = 'Florian Rhiem <f.rhiem@fz-juelich.de>'
 def instrument_to_json(instrument):
     return {
         'instrument_id': instrument.id,
-        'name': instrument.name,
-        'description': instrument.description,
+        'name': instrument.translation.name,
+        'description': instrument.translation.description,
         'is_hidden': instrument.is_hidden,
         'instrument_scientists': [user.id for user in instrument.responsible_users]
     }
@@ -26,7 +27,10 @@ class Instrument(Resource):
     @multi_auth.login_required
     def get(self, instrument_id: int):
         try:
-            instrument = get_instrument(instrument_id=instrument_id)
+            instrument = get_instrument_with_translation_in_language(
+                instrument_id=instrument_id,
+                language_id=Language.ENGLISH
+            )
         except errors.InstrumentDoesNotExistError:
             return {
                 "message": "instrument {} does not exist".format(instrument_id)
@@ -37,5 +41,7 @@ class Instrument(Resource):
 class Instruments(Resource):
     @multi_auth.login_required
     def get(self):
-        instruments = get_instruments()
+        instruments = get_instruments_with_translation_in_language(
+            language_id=Language.ENGLISH
+        )
         return [instrument_to_json(instrument) for instrument in instruments]
