@@ -17,6 +17,7 @@ class ActionType(db.Model):
     SAMPLE_CREATION = -100 + 1
     MEASUREMENT = -100 + 2
     SIMULATION = -100 + 3
+    TEMPLATE = -100 + 4
 
     id = db.Column(db.Integer, primary_key=True)
     admin_only = db.Column(db.Boolean, nullable=False, default=False)
@@ -30,6 +31,8 @@ class ActionType(db.Model):
     enable_activity_log = db.Column(db.Boolean, nullable=False, default=True)
     enable_related_objects = db.Column(db.Boolean, nullable=False, default=True)
     enable_project_link = db.Column(db.Boolean, nullable=False, default=False, server_default=db.false())
+    disable_create_objects = db.Column(db.Boolean, nullable=False, default=False, server_default=db.false())
+    is_template = db.Column(db.Boolean, nullable=False, default=False, server_default=db.false())
 
     def __repr__(self):
         return '<{0}(id={1.id!r}, name={1.name!r})>'.format(type(self).__name__, self)
