@@ -26,6 +26,9 @@ class ObjectLogEntryType(enum.Enum):
     ASSIGN_LOCATION = 9
     LINK_PUBLICATION = 10
     REFERENCE_OBJECT_IN_METADATA = 11
+    EXPORT_TO_DATAVERSE = 12
+    LINK_PROJECT = 13
+    UNLINK_PROJECT = 14
 
 
 class ObjectLogEntry(db.Model):
