@@ -6,7 +6,8 @@ Usage: python -m sampledb list_instruments
 """
 
 from .. import create_app
-from ..logic.instruments import get_instruments
+from ..logic.instrument_translations import get_instruments_with_translation_in_language
+from ..logic.languages import Language
 
 
 def main(arguments):
@@ -15,6 +16,6 @@ def main(arguments):
         exit(1)
     app = create_app()
     with app.app_context():
-        instruments = get_instruments()
+        instruments = get_instruments_with_translation_in_language(Language.ENGLISH)
         for instrument in instruments:
-            print(" - #{0.id}: {0.name}".format(instrument))
+            print(" - #{0.id}: {0.translation.name}".format(instrument))
